from Products.Archetypes.public import *
from Products.CMFCore import CMFCorePermissions
from DateTime import DateTime

from Products.ATContentTypes.content.base import ATCTOrderedFolder, updateActions
from Products.ATContentTypes.content.document import finalizeATCTSchema

from Products.ATContentTypes.lib.constraintypes import ConstrainTypesMixinSchema

schema = ATCTOrderedFolder.schema.copy() + ConstrainTypesMixinSchema + Schema((
    StringField('description',
                isMetadata=1,
                accessor='Description',
                searchable=1,                
                widget=TextAreaWidget(label='Description', description='Give a short description for this template.'),),
    TextField('usage',
                searchable=1,
                required=0,
                primary=1,
                default_output_type='text/html', 
                default_content_type='text/html',
                allowable_content_types=('text/html',),
                widget=RichWidget(allow_file_upload=0, label='Usage', 
                                  allow_format_edit=0,
                                  description="Describe the how this template should be used and what it's purpose it.")),
    BooleanField('showUsage',
                 default = False,
                 widget=BooleanWidget(label='Show template description and usage before instantiation', 
                                      description='When checked, a page with the usage info will be displayed to the user before the actual template will be instantiated.')),
        ))

finalizeATCTSchema(schema)

class Template(ATCTOrderedFolder):
    """A Template is a container that can hold any kind of content. After
the Template is registered in a folder (or any other template-aware
folderish item), a user can instantiate whatever is inside the
Template container by using the templates drop-down menu next to the
add item menu.
    """
    portal_type = meta_type = 'Template'
    archetype_name = 'Template'
    schema = schema
    content_icon='template_icon.gif'
    allowed_content_types=()
    default_view = 'template_view'
    immediate_view = 'template_view'
    _at_rename_after_creation = True    
    allow_discussion = 0
    global_allow=1

    def getAutoIcon(self):
        """ Return the icon of the first contained object in this template """
        items = self.getFolderContents(contentFilter={'sort_on':'getObjPositionInParent'})
        if len(items)>0:
            return items[0].getIcon
        else:
            return self.content_icon
    
registerType(Template)

